<?php
/**
 * croatian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Tomo Krajina <aaa@puzz.info>
 * @author Branko Rihtman <theney@gmail.com>
 * @author Dražen Odobašić <dodobasic@gmail.com>
 * @author Dejan Igrec dejan.igrec@gmail.com
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Izmijeni dokument';
$lang['btn_source']            = 'Prikaži kod dokumenta';
$lang['btn_show']              = 'Prikaži dokument';
$lang['btn_create']            = 'Novi dokument';
$lang['btn_search']            = 'Pretraži';
$lang['btn_save']              = 'Spremi';
$lang['btn_preview']           = 'Prikaži';
$lang['btn_top']               = 'Na vrh';
$lang['btn_newer']             = '<< noviji';
$lang['btn_older']             = 'stariji >>';
$lang['btn_revs']              = 'Stare inačice';
$lang['btn_recent']            = 'Nedavne izmjene';
$lang['btn_upload']            = 'Postavi';
$lang['btn_cancel']            = 'Odustani';
$lang['btn_index']             = 'Indeks';
$lang['btn_secedit']           = 'Izmjeni';
$lang['btn_login']             = 'Prijavi se';
$lang['btn_logout']            = 'Odjavi se';
$lang['btn_admin']             = 'Administriranje';
$lang['btn_update']            = 'Ažuriraj';
$lang['btn_delete']            = 'Obriši';
$lang['btn_back']              = 'Povratak';
$lang['btn_backlink']          = 'Povratni linkovi';
$lang['btn_backtomedia']       = 'Povratak na Mediafile izbornik';
$lang['btn_subscribe']         = 'Pretplati se na promjene dokumenta';
$lang['btn_profile']           = 'Ažuriraj profil';
$lang['btn_reset']             = 'Poništi promjene';
$lang['btn_draft']             = 'Uredi nacrt dokumenta';
$lang['btn_recover']           = 'Vrati prijašnji nacrt dokumenta';
$lang['btn_draftdel']          = 'Obriši nacrt dokumenta';
$lang['btn_revert']            = 'Vrati';
$lang['btn_register']          = 'Registracija';
$lang['loggedinas']            = 'Prijavljen kao';
$lang['user']                  = 'Korisničko ime';
$lang['pass']                  = 'Lozinka';
$lang['newpass']               = 'Nova lozinka';
$lang['oldpass']               = 'Potvrdi trenutnu lozinku';
$lang['passchk']               = 'Ponoviti';
$lang['remember']              = 'Zapamti me';
$lang['fullname']              = 'Ime i prezime';
$lang['email']                 = 'Email';
$lang['profile']               = 'Korisnički profil';
$lang['badlogin']              = 'Ne ispravno korisničko ime ili lozinka.';
$lang['minoredit']             = 'Manje izmjene';
$lang['draftdate']             = 'Nacrt dokumenta je automatski spremljen u ';
$lang['nosecedit']             = 'Stranica se u međuvremenu promijenila. Informacija o odjeljku je ostarila pa je učitana kompletna stranica.';
$lang['regmissing']            = 'Morate popuniti sva polja.';
$lang['reguexists']            = 'Korisnik s tim korisničkim imenom već postoji.';
$lang['regsuccess']            = 'Korisnik je uspješno stvoren i poslana je lozinka emailom.';
$lang['regsuccess2']           = 'Korisnik je uspješno stvoren.';
$lang['regmailfail']           = 'Pojavila se greška prilikom slanja lozinke emailom. Kontaktirajte administratora!';
$lang['regbadmail']            = 'Email adresa nije ispravna, ukoliko ovo smatrate greškom, kontaktirajte administratora.';
$lang['regbadpass']            = 'Unesene lozinke nisu jednake, pokušajte ponovno.';
$lang['regpwmail']             = 'Vaša DokuWiki lozinka';
$lang['reghere']               = 'Još uvijek nemate korisnički račun? Registrirajte se.';
$lang['profna']                = 'Ovaj wiki ne dopušta izmjene korisničkog profila.';
$lang['profnochange']          = 'Nema izmjena.';
$lang['profnoempty']           = 'Prazno korisničko ime ili email nisu dopušteni.';
$lang['profchanged']           = 'Korisnički profil je uspješno izmijenjen.';
$lang['pwdforget']             = 'Izgubili ste lozinku? Zatražite novu';
$lang['resendna']              = 'Ovaj wiki ne podržava ponovno slanje lozinke emailom.';
$lang['resendpwdmissing']      = 'Ispunite sva polja.';
$lang['resendpwdnouser']       = 'Nije moguće pronaći korisnika.';
$lang['resendpwdbadauth']      = 'Neispravan autorizacijski kod. Provjerite da li ste koristili potpun potvrdni link.';
$lang['resendpwdconfirm']      = 'Potvrdni link je poslan emailom.';
$lang['resendpwdsuccess']      = 'Nova lozinka je poslana emailom.';
$lang['license']               = 'Osim na mjestima gdje je naznačeno drugačije, sadržaj ovog wikija je licenciran sljedećom licencom:';
$lang['licenseok']             = 'Pažnja: promjenom ovog dokumenta pristajete licencirati sadržaj sljedećom licencom: ';
$lang['searchmedia']           = 'Traži naziv datoteke:';
$lang['searchmedia_in']        = 'Traži u %s';
$lang['txt_upload']            = 'Odaberite datoteku za postavljanje';
$lang['txt_filename']          = 'Postaviti kao (nije obavezno)';
$lang['txt_overwrt']           = 'Prepiši postojeću datoteku';
$lang['lockedby']              = 'Zaključao';
$lang['lockexpire']            = 'Zaključano do';
$lang['js']['willexpire']            = 'Dokument kojeg mijenjate će biti zaključan još 1 minutu.\n Ukoliko želite i dalje raditi izmjene na dokumentu - kliknite na "Pregled".';
$lang['js']['notsavedyet']     = 'Vaše izmjene će se izgubiti.
Želite li nastaviti?';
$lang['js']['searchmedia']     = 'Traži datoteke';
$lang['js']['keepopen']        = 'Ostavi prozor otvoren nakon izbora';
$lang['js']['hidedetails']     = 'Sakrij detalje';
$lang['js']['mediatitle']      = 'Postavke poveznice';
$lang['js']['mediadisplay']    = 'Vrsta poveznice';
$lang['js']['mediaalign']      = 'Poravnanje';
$lang['js']['mediasize']       = 'Veličina slike';
$lang['js']['mediatarget']     = 'Cilj poveznice';
$lang['js']['mediaclose']      = 'Zatvori';
$lang['js']['mediainsert']     = 'Umetni';
$lang['js']['mediadisplayimg'] = 'Prikaži sliku.';
$lang['js']['mediadisplaylnk'] = 'Prikaži samo poveznicu.';
$lang['js']['mediasmall']      = 'Mala verzija.';
$lang['js']['mediamedium']     = 'Srednja verzija.';
$lang['js']['medialarge']      = 'Velika verzija.';
$lang['js']['mediaoriginal']   = 'Originalna verzija.';
$lang['js']['medialnk']        = 'Poveznica na stranicu s detaljima';
$lang['js']['mediadirect']     = 'Direktna poveznica na original';
$lang['js']['medianolnk']      = 'Bez poveznice';
$lang['js']['medianolink']     = 'Nemoj povezati sliku';
$lang['js']['medialeft']       = 'Poravnaj sliku lijevo.';
$lang['js']['mediaright']      = 'Poravnaj sliku desno.';
$lang['js']['mediacenter']     = 'Poravnaj sliku u sredinu.';
$lang['js']['medianoalign']    = 'Bez poravnanja.';
$lang['js']['nosmblinks']      = 'Linkovi na dijeljene Windows mape rade samo s Internet Explorerom. Link je još uvijek moguće kopirati i zalijepiti.';
$lang['js']['linkwiz']         = 'Čarobnjak za poveznice';
$lang['js']['linkto']          = 'Poveznica na:';
$lang['js']['del_confirm']     = 'Zbilja želite obrisati odabrane stavke?';
$lang['rssfailed']             = 'Došlo je do greške prilikom preuzimanja feed-a: ';
$lang['nothingfound']          = 'Traženi dokumetni nisu pronađeni.';
$lang['mediaselect']           = 'Mediafile datoteke';
$lang['fileupload']            = 'Mediafile postavljanje';
$lang['uploadsucc']            = 'Postavljanje uspješno';
$lang['uploadfail']            = 'Neuspješno postavljanje. Možda dozvole na poslužitelju nisu ispravne?';
$lang['uploadwrong']           = 'Postavljanje nije dopušteno. Nastavak datoteke je zabranjen!';
$lang['uploadexist']           = 'Datoteka već postoji.';
$lang['uploadbadcontent']      = 'Postavljeni sadržaj ne odgovara ekstenziji %s datoteke.';
$lang['uploadspam']            = 'Postavljanje je blokirano spam crnom listom.';
$lang['uploadxss']             = 'Postavljanje je blokirano zbog mogućeg zlonamjernog sadržaja.';
$lang['uploadsize']            = 'Postavljena datoteka je prevelika (max. %s)';
$lang['deletesucc']            = 'Datoteka "%s" je obrisana.';
$lang['deletefail']            = '"%s" se ne može obrisati - provjerite dozvole na poslužitelju.';
$lang['mediainuse']            = 'Datoteka "%s" nije obrisana - još uvijek se koristi.';
$lang['namespaces']            = 'Imenski prostori';
$lang['mediafiles']            = 'Datoteke u';
$lang['accessdenied']          = 'Nemate potrebne dozvole za pregled ove stranice.';
$lang['mediausage']            = 'Koristi sljedeću sintaksu za referenciranje ove datoteke:';
$lang['mediaview']             = 'Pregledaj originalnu datoteku';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Postavi datoteku u odabrani imenski prostor. Podimenski prostori se stvaraju dodavanjem istih kao prefiks naziva datoteke u "Postavi kao" polju, tako da se odvoje dvotočkama.';
$lang['mediaextchange']        = 'Ekstenzija datoteke promijenjena iz .%s u .%s!';
$lang['reference']             = 'Reference za';
$lang['ref_inuse']             = 'Datoteka se ne može obrisati jer se još uvijek koristi u sljedećim dokumentima:';
$lang['ref_hidden']            = 'Neke reference se nalaze na dokumentima koje nemate dozvolu čitati';
$lang['hits']                  = 'Pronađeno';
$lang['quickhits']             = 'Pronađeno po nazivima dokumenata';
$lang['toc']                   = 'Sadržaj';
$lang['current']               = 'trenutno';
$lang['yours']                 = 'Vaša inačica';
$lang['diff']                  = 'Prikaži razlike u odnosu na trenutnu inačicu';
$lang['diff2']                 = 'Pokaži razlike između odabranih inačica';
$lang['difflink']              = 'Poveznica na ovaj prikaz usporedbe';
$lang['diff_type']             = 'Razlike u prikazu:';
$lang['diff_inline']           = 'U istoj razini';
$lang['diff_side']             = 'Usporedo';
$lang['line']                  = 'Redak';
$lang['breadcrumb']            = 'Putanja';
$lang['youarehere']            = 'Vi ste ovdje';
$lang['lastmod']               = 'Zadnja izmjena';
$lang['by']                    = 'od';
$lang['deleted']               = 'obrisano';
$lang['created']               = 'stvoreno';
$lang['restored']              = 'vraćena prijašnja inačica (%s)';
$lang['external_edit']         = 'vanjsko uređivanje';
$lang['summary']               = 'Sažetak izmjena';
$lang['noflash']               = 'Za prikazivanje ovog sadržaja potreban je <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>';
$lang['download']              = 'Preuzmi isječak';
$lang['mail_newpage']          = 'stranica dodana:';
$lang['mail_changed']          = 'stranica izmjenjena:';
$lang['mail_subscribe_list']   = 'stranice promijenjene u imenskom prostoru:';
$lang['mail_new_user']         = 'novi korisnik:';
$lang['mail_upload']           = 'datoteka postavljena:';
$lang['qb_bold']               = 'Podebljani tekst';
$lang['qb_italic']             = 'Ukošeni tekst';
$lang['qb_underl']             = 'Podcrtani tekst';
$lang['qb_code']               = 'Kod';
$lang['qb_strike']             = 'Precrtani tekst';
$lang['qb_h1']                 = 'Naslov - razina 1';
$lang['qb_h2']                 = 'Naslov - razina 2';
$lang['qb_h3']                 = 'Naslov - razina 3';
$lang['qb_h4']                 = 'Naslov - razina 4';
$lang['qb_h5']                 = 'Naslov - razina 5';
$lang['qb_h']                  = 'Naslov';
$lang['qb_hs']                 = 'Odaberite naslov';
$lang['qb_hplus']              = 'Naslov više razine';
$lang['qb_hminus']             = 'Naslov niže razine';
$lang['qb_hequal']             = 'Naslov iste razine';
$lang['qb_link']               = 'Interni link';
$lang['qb_extlink']            = 'Vanjski link';
$lang['qb_hr']                 = 'Vodoravna crta';
$lang['qb_ol']                 = 'Pobrojana lista';
$lang['qb_ul']                 = 'Lista';
$lang['qb_media']              = 'Dodaj slike i ostale datoteke';
$lang['qb_sig']                = 'Potpis';
$lang['qb_smileys']            = 'Smiješkići';
$lang['qb_chars']              = 'Posebni znakovi';
$lang['upperns']               = 'Skoči u nadređeni imenski prostor';
$lang['admin_register']        = 'Dodaj novog korisnika';
$lang['metaedit']              = 'Uredi metapodatake';
$lang['metasaveerr']           = 'Neuspješno zapisivanje metapodataka';
$lang['metasaveok']            = 'Spremljeni metapdaci';
$lang['btn_img_backto']            = 'Povratak na %s';
$lang['img_title']             = 'Naziv';
$lang['img_caption']           = 'Naslov';
$lang['img_date']              = 'Datum';
$lang['img_fname']             = 'Ime datoteke';
$lang['img_fsize']             = 'Veličina';
$lang['img_artist']            = 'Fotograf';
$lang['img_copyr']             = 'Autorsko pravo';
$lang['img_format']            = 'Format';
$lang['img_camera']            = 'Kamera';
$lang['img_keywords']          = 'Ključne riječi';
$lang['subscr_subscribe_success'] = 'Dodan %s u listu pretplatnika za %s';
$lang['subscr_subscribe_error'] = 'Greška kod dodavanja %s u listu pretplatnika za %s';
$lang['subscr_subscribe_noaddress'] = 'Ne postoji adresa povezana sa vašim podacima za prijavu, stoga ne možete biti dodani u listu pretplatnika';
$lang['subscr_unsubscribe_success'] = 'Uklonjen %s iz liste pretplatnika za %s';
$lang['subscr_unsubscribe_error'] = 'Greška prilikom uklanjanja %s iz liste pretplatnika za %s';
$lang['subscr_already_subscribed'] = '%s je već pretplaćen na %s';
$lang['subscr_not_subscribed'] = '%s nije pretplaćen na %s';
$lang['subscr_m_not_subscribed'] = 'Trenutno niste pretplaćeni na trenutnu stranicu ili imenski prostor.';
$lang['subscr_m_new_header']   = 'Dodaj pretplatu';
$lang['subscr_m_current_header'] = 'Trenutne pretplate';
$lang['subscr_m_unsubscribe']  = 'Odjavi pretplatu';
$lang['subscr_m_subscribe']    = 'Pretplati se';
$lang['subscr_m_receive']      = 'Primaj';
$lang['subscr_style_every']    = 'email za svaku promjenu';
$lang['subscr_style_digest']   = 'email s kratakim prikazom promjena za svaku stranicu (svaka %.2f dana)';
$lang['subscr_style_list']     = 'listu promijenjenih stranica od zadnjeg primljenog email-a (svaka %.2f dana)';
$lang['authtempfail']          = 'Autentifikacija korisnika je privremeno nedostupna. Molimo Vas da kontaktirate administratora.';
$lang['i_chooselang']          = 'Izaberite vaš jezik';
$lang['i_installer']           = 'DokuWiki instalacija';
$lang['i_wikiname']            = 'Naziv Wikija';
$lang['i_enableacl']           = 'Omogući ACL (preporučeno)';
$lang['i_superuser']           = 'Superkorisnik';
$lang['i_problems']            = 'Instalacija je pronašla probleme koji su naznačeni ispod. Nije moguće nastaviti dok se ti problemi ne riješe.';
$lang['i_modified']            = 'Zbog sigurnosnih razlog, ova skripta ce raditi samo sa novim i nepromijenjenim instalacijama dokuWikija. Preporucujemo da ili re-ekstraktirate fajlove iz downloadovanog paketa ili konsultujete pune a href="http://dokuwiki.org/install">Instrukcije za instalaciju Dokuwikija</a>';
$lang['i_funcna']              = 'PHP funkcija <code>%s</code> nije dostupna. Možda ju je vaš pružatelj hostinga onemogućio iz nekog razloga?';
$lang['i_phpver']              = 'Vaša PHP verzija <code>%s</code> je niža od potrebne <code>%s</code>. Trebate nadograditi vašu PHP instalaciju.';
$lang['i_permfail']            = '<code>%s</code> nema dozvolu pisanja od strane DokuWiki. Trebate podesiti dozvole pristupa tom direktoriju.';
$lang['i_confexists']          = '<code>%s</code> već postoji';
$lang['i_writeerr']            = 'Ne može se kreirati <code>%s</code>. Trebate provjeriti dozvole direktorija/datoteke i kreirati dokument ručno.';
$lang['i_badhash']             = 'neprepoznat ili promijenjen dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - nedozvoljena ili prazna vrijednost';
$lang['i_success']             = 'Konfiguracija je uspješno završena. Sada možete obrisati install.php datoteku. Nastavite na <a href="doku.php?id=wiki:welcome">vaš novi DokuWiki</a>.';
$lang['i_failure']             = 'Pojavile su se neke greške prilikom pisanja konfiguracijskih datoteka. Morati ćete ih ručno ispraviti da bi mogli koristiti <a href="doku.php?id=wiki:welcome">vaš novi DokuWiki</a>.';
$lang['i_policy']              = 'Inicijalna ACL politika';
$lang['i_pol0']                = 'Otvoreni Wiki (čitanje, pisanje, učitavanje za sve)';
$lang['i_pol1']                = 'Javni Wiki (čitanje za sve, pisanje i učitavanje za registrirane korisnike)';
$lang['i_pol2']                = 'Zatvoreni Wiki (čitanje, pisanje, učitavanje samo za registrirane korisnike)';
$lang['i_retry']               = 'Pokušaj ponovo';
$lang['i_license']             = 'Molim odaberite licencu pod kojom želite postavljati vaš sadržaj:';
$lang['recent_global']         = 'Trenutno gledate promjene unutar <b>%s</b> imenskog prostora. Također možete <a href="%s">vidjeti zadnje promjene cijelog wiki-a</a>';
$lang['years']                 = '%d godina prije';
$lang['months']                = '%d mjeseci prije';
$lang['weeks']                 = '%d tjedana prije';
$lang['days']                  = '%d dana prije';
$lang['hours']                 = '%d sati prije';
$lang['minutes']               = '%d minuta prije';
$lang['seconds']               = '%d sekundi prije';
$lang['wordblock']             = 'Vaša promjena nije spremljena jer sadrži blokirani tekst (spam).';
